@@ -27,7 +27,8 @@
 #' 
 #' @return a vector with file paths
 #' @author Berry Boessenkool, \email{berry-b@@gmx.de}, Oct 2016
-#' @seealso [createIndex()], [updateIndexes()]
+#' @seealso [createIndex()], [updateIndexes()],
+#'          [website index chapter](https://bookdown.org/brry/rdwd/fileindex.html)
 #' @keywords file
 #' @importFrom stats runif
 #' @importFrom pbapply pblapply
@@ -132,8 +133,8 @@ if(progbar) lapply <- pbapply::pblapply
 curl_handle <- RCurl::getCurlHandle(ftp.use.epsv=TRUE)
 
 # remove trailing slashes in base and leading slashes in folder:
-while(grepl("/$", base)) base <- sub("/$", "", base)
-while(any(grepl("^/", folder))) folder <- sub("^/","",folder)
+base <- sub("/+$", "", base)
+folder <- sub("^/+","",folder)
 
 # central object: df_ff (dataframe with file/folder names)
 df_ff <- data.frame(path=folder, isfile=FALSE, stringsAsFactors=FALSE)
