@@ -37,7 +37,7 @@
 #'         "base/res/var/per/filename.zip"
 #' @author Berry Boessenkool, \email{berry-b@@gmx.de}, Oct 2016
 #' @seealso [dataDWD()], [`metaIndex`],
-#'          <https://bookdown.org/brry/rdwd>
+#'          [website station selection chapter](https://bookdown.org/brry/rdwd/station-selection.html#by-name)
 #' @keywords file
 #' @importFrom berryFunctions truncMessage traceCall
 #' @importFrom utils menu
@@ -375,7 +375,7 @@ if(givenid & givenpath & !meta[i])
             "https://github.com/brry/rdwd/issues\n - Keeping: ", filename, call.=FALSE)
     } else
     filename <- findex[sel,"path"]
-  if(length(filename)>1) warning(traceCall(3, "", ": "), "several files (",
+  if(length(filename)>1 && !quiet) warning(traceCall(3, "", ": "), "several files (",
                                  length(filename),") were selected:",
                                  berryFunctions::truncMessage(filename, prefix=""),
                                  call.=FALSE)
